import numpy as np
import matplotlib.pyplot as plt
from scipy.integrate import odeint
from mpl_toolkits.mplot3d import Axes3D

def func(r, t):
    x, y, z = r
    
    dxdt = sigma*(y - x)    # The Lorenz equations
    dydt = x*(rho - z) - y
    dzdt = x*y - beta*z
    
    return dxdt, dydt, dzdt

r0 = (0.1, 0.0, 0.0)    # Initial position 

sigma = 10.0            # Constants
rho   = 28.0
beta  = 8.0/3.0

t = np.linspace(0, 100, 10000)

pos = odeint(func, r0, t)

x = pos[:, 0]
y = pos[:, 1]
z = pos[:, 2]

fig = plt.figure(figsize=(12,10))
ax = fig.gca(projection='3d')

ax.plot(x, y, z)

plt.show()
